#!/usr/bin/env python

"""Tests for `r_freeze` package."""


import pytest

from r_freeze import r_freeze

def test_ok():
    print("ok")
